[asterisk-commits] jpeeler: branch jpeeler/chan_dahdi r118612 - /team/jpeeler/chan_dahdi/channels/

SVN commits to the Asterisk project asterisk-commits at lists.digium.com
Tue May 27 17:11:39 CDT 2008


Author: jpeeler
Date: Tue May 27 17:11:38 2008
New Revision: 118612

URL: http://svn.digium.com/view/asterisk?view=rev&rev=118612
Log:
chan_dahdi is configured with chan_dahdi.conf

Modified:
    team/jpeeler/chan_dahdi/channels/chan_dahdi.c

Modified: team/jpeeler/chan_dahdi/channels/chan_dahdi.c
URL: http://svn.digium.com/view/asterisk/team/jpeeler/chan_dahdi/channels/chan_dahdi.c?view=diff&rev=118612&r1=118611&r2=118612
==============================================================================
--- team/jpeeler/chan_dahdi/channels/chan_dahdi.c (original)
+++ team/jpeeler/chan_dahdi/channels/chan_dahdi.c Tue May 27 17:11:38 2008
@@ -175,7 +175,7 @@
 #endif
 ;
 
-static const char config[] = "dahdi.conf";
+static const char config[] = "chan_dahdi.conf";
 
 #define SIG_EM		DAHDI_SIG_EM
 #define SIG_EMWINK 	(0x0100000 | DAHDI_SIG_EM)
@@ -714,8 +714,8 @@
 	int muting;
 } *iflist = NULL, *ifend = NULL;
 
 /*! \brief Channel configuration from dahdi.conf .
  * This struct is used for parsing the [channels] section of dahdi.conf.
  * Generally there is a field here for every possible configuration item.
  *
  * The state of fields is saved along the parsing and whenever a 'channel'
@@ -6952,7 +6952,7 @@
 								if (p->ringt < p->ringt_base/2)
 									break;
 								/* Increment the ringT counter so we can match it against
-								   values in dahdi.conf for distinctive ring */
+								   values in chan_dahdi.conf for distinctive ring */
 								if (++receivedRingT == (sizeof(curRingData) / sizeof(curRingData[0])))
 									break;
 							} else if (i & DAHDI_IOMUX_READ) {
@@ -6977,7 +6977,7 @@
 							/* this only shows up if you have n of the dring patterns filled in */
 						ast_verb(3, "Detected ring pattern: %d,%d,%d\n",curRingData[0],curRingData[1],curRingData[2]);
 						for (counter = 0; counter < 3; counter++) {
 							/* Check to see if the rings we received match any of the ones in dahdi.conf for this
 							channel */
 							distMatches = 0;
 							for (counter1 = 0; counter1 < 3; counter1++) {
@@ -7111,7 +7111,7 @@
 						if (p->ringt < p->ringt_base/2)
 							break;
 						/* Increment the ringT counter so we can match it against
-						   values in dahdi.conf for distinctive ring */
+						   values in chan_dahdi.conf for distinctive ring */
 						if (++receivedRingT == (sizeof(curRingData) / sizeof(curRingData[0])))
 							break;
 					} else if (i & DAHDI_IOMUX_READ) {
@@ -7172,7 +7172,7 @@
 							if (p->ringt < p->ringt_base/2)
 								break;
 							/* Increment the ringT counter so we can match it against
-							   values in dahdi.conf for distinctive ring */
+							   values in chan_dahdi.conf for distinctive ring */
 							if (++receivedRingT == (sizeof(curRingData) / sizeof(curRingData[0])))
 								break;
 						} else if (i & DAHDI_IOMUX_READ) {
@@ -7200,7 +7200,7 @@
 					ast_verb(3, "Detected ring pattern: %d,%d,%d\n",curRingData[0],curRingData[1],curRingData[2]);
 
 					for (counter = 0; counter < 3; counter++) {
 						/* Check to see if the rings we received match any of the ones in dahdi.conf for this
 						channel */
 							/* this only shows up if you have n of the dring patterns filled in */
 						ast_verb(3, "Checking %d,%d,%d\n",
@@ -8065,7 +8065,7 @@
 #endif /* HAVE_SS7 */
 
 /* converts a DAHDI sigtype to signalling as can be configured from
- * dahdi.conf.
+ * chan_dahdi.conf.
  * While both have basically the same values, this will later be the
  * place to add filters and sanity checks
  */
@@ -11785,7 +11785,7 @@
 		e->usage = 
 			"Usage: dahdi restart\n"
 			"	Restarts the DAHDI channels: destroys them all and then\n"
-			"	re-reads them from dahdi.conf.\n"
+			"	re-reads them from chan_dahdi.conf.\n"
 			"	Note that this will STOP any running CALL on DAHDI channels.\n"
 			"";
 		return NULL;
@@ -12875,7 +12875,7 @@
 				) {
 			dahdi_close(link->fds[curfd]);
 			link->fds[curfd] = -1;
-			ast_log(LOG_ERROR, "sigchan %d is not in HDLC/FCS mode.  See /etc/dahditel.conf\n", sigchan);
+			ast_log(LOG_ERROR, "sigchan %d is not in HDLC/FCS mode.  See /etc/dahdi.conf\n", sigchan);
 			return -1;
 		}
 
@@ -14179,22 +14179,22 @@
 						while (c && (i < NUM_DCHANS)) {
 							dchannels[i] = atoi(c + 1);
 							if (dchannels[i] < 0) {
-								ast_log(LOG_WARNING, "D-channel for trunk group %d must be a postiive number at line %d of dahdi.conf\n", trunkgroup, v->lineno);
+								ast_log(LOG_WARNING, "D-channel for trunk group %d must be a postiive number at line %d of chan_dahdi.conf\n", trunkgroup, v->lineno);
 							} else
 								i++;
 							c = strchr(c + 1, ',');
 						}
 						if (i) {
 							if (pri_create_trunkgroup(trunkgroup, dchannels)) {
-								ast_log(LOG_WARNING, "Unable to create trunk group %d with Primary D-channel %d at line %d of dahdi.conf\n", trunkgroup, dchannels[0], v->lineno);
+								ast_log(LOG_WARNING, "Unable to create trunk group %d with Primary D-channel %d at line %d of chan_dahdi.conf\n", trunkgroup, dchannels[0], v->lineno);
 						} else
 								ast_verb(2, "Created trunk group %d with Primary D-channel %d and %d backup%s\n", trunkgroup, dchannels[0], i - 1, (i == 1) ? "" : "s");
 						} else
-							ast_log(LOG_WARNING, "Trunk group %d lacks any valid D-channels at line %d of dahdi.conf\n", trunkgroup, v->lineno);
+							ast_log(LOG_WARNING, "Trunk group %d lacks any valid D-channels at line %d of chan_dahdi.conf\n", trunkgroup, v->lineno);
 					} else
-						ast_log(LOG_WARNING, "Trunk group %d lacks a primary D-channel at line %d of dahdi.conf\n", trunkgroup, v->lineno);
+						ast_log(LOG_WARNING, "Trunk group %d lacks a primary D-channel at line %d of chan_dahdi.conf\n", trunkgroup, v->lineno);
 				} else
-					ast_log(LOG_WARNING, "Trunk group identifier must be a positive integer at line %d of dahdi.conf\n", v->lineno);
+					ast_log(LOG_WARNING, "Trunk group identifier must be a positive integer at line %d of chan_dahdi.conf\n", v->lineno);
 			} else if (!strcasecmp(v->name, "spanmap")) {
 				spanno = atoi(v->value);
 				if (spanno > 0) {
@@ -14211,13 +14211,13 @@
 							} else
 									ast_verb(2, "Mapped span %d to trunk group %d (logical span %d)\n", spanno, trunkgroup, logicalspan);
 							} else
-								ast_log(LOG_WARNING, "Logical span must be a postive number, or '0' (for unspecified) at line %d of dahdi.conf\n", v->lineno);
+								ast_log(LOG_WARNING, "Logical span must be a postive number, or '0' (for unspecified) at line %d of chan_dahdi.conf\n", v->lineno);
 						} else
-							ast_log(LOG_WARNING, "Trunk group must be a postive number at line %d of dahdi.conf\n", v->lineno);
+							ast_log(LOG_WARNING, "Trunk group must be a postive number at line %d of chan_dahdi.conf\n", v->lineno);
 					} else
-						ast_log(LOG_WARNING, "Missing trunk group for span map at line %d of dahdi.conf\n", v->lineno);
+						ast_log(LOG_WARNING, "Missing trunk group for span map at line %d of chan_dahdi.conf\n", v->lineno);
 				} else
-					ast_log(LOG_WARNING, "Span number must be a postive integer at line %d of dahdi.conf\n", v->lineno);
+					ast_log(LOG_WARNING, "Span number must be a postive integer at line %d of chan_dahdi.conf\n", v->lineno);
 			} else {
 				ast_log(LOG_NOTICE, "Ignoring unknown keyword '%s' in trunkgroups\n", v->name);
 			}
@@ -14241,7 +14241,7 @@
 		return res;
 	}
 
 	/* Now get configuration from all normal sections in dahdi.conf: */
 	for (cat = ast_category_browse(cfg, NULL); cat ; cat = ast_category_browse(cfg, cat)) {
 		/* [channels] and [trunkgroups] are used. Let's also reserve
 		 * [globals] and [general] for future use
@@ -714,8 +714,8 @@
 } *iflist = NULL, *ifend = NULL;
 
-/*! \brief Channel configuration from dahdi.conf .
- * This struct is used for parsing the [channels] section of dahdi.conf.
+/*! \brief Channel configuration from chan_dahdi.conf .
+ * This struct is used for parsing the [channels] section of chan_dahdi.conf.
  * Generally there is a field here for every possible configuration item.
  *
@@ -6977,7 +6977,7 @@
 						ast_verb(3, "Detected ring pattern: %d,%d,%d\n",curRingData[0],curRingData[1],curRingData[2]);
 						for (counter = 0; counter < 3; counter++) {
-							/* Check to see if the rings we received match any of the ones in dahdi.conf for this
+							/* Check to see if the rings we received match any of the ones in chan_dahdi.conf for this
 							channel */
 							distMatches = 0;
@@ -7200,7 +7200,7 @@
 
 					for (counter = 0; counter < 3; counter++) {
-						/* Check to see if the rings we received match any of the ones in dahdi.conf for this
+						/* Check to see if the rings we received match any of the ones in chan_dahdi.conf for this
 						channel */
 							/* this only shows up if you have n of the dring patterns filled in */
@@ -14241,7 +14241,7 @@
 	}
 
-	/* Now get configuration from all normal sections in dahdi.conf: */
+	/* Now get configuration from all normal sections in chan_dahdi.conf: */
 	for (cat = ast_category_browse(cfg, NULL); cat ; cat = ast_category_browse(cfg, cat)) {
 		/* [channels] and [trunkgroups] are used. Let's also reserve




More information about the asterisk-commits mailing list